from typing import List

from pydantic import BaseModel

# Order of models is defined by the order of occurrence in the bettermarks plugin


class User(BaseModel):  # response model
    user_id: str
    username: str
    firstname: str
    lastname: str
    type: str
    school_id: str

    class Config:
        schema_extra = {
            "example": {
                "user_id": "4378687645",
                "username": "foo",
                "firstname": "First",
                "lastname": "Name",
                "type": "teacher",
                "school_id": "s789",
            }
        }


class Schoolclass(BaseModel):
    group_id: str
    name: str


class CountedSchoolclass(Schoolclass):
    student_count: int


class UsersClasses(BaseModel):  # response model
    groups: List[CountedSchoolclass]

    class Config:
        schema_extra = {
            "example": {
                "groups": [
                    {"group_id": "123", "name": "Group 1", "student_count": 2},
                    {"group_id": "456", "name": "Group 2", "student_count": 4},
                ]
            }
        }


class Teacher(BaseModel):
    user_id: str
    username: str


class Student(Teacher):
    firstname: str
    lastname: str


class ClassMembers(BaseModel):  # response model
    students: List[Student]
    teachers: List[Teacher]

    class Config:
        schema_extra = {
            "example": {
                "students": [
                    {
                        "user_id": "u123",
                        "username": "janedoe",
                        "firstname": "Jane",
                        "lastname": "Doe",
                    },
                    {
                        "user_id": "u124",
                        "username": "johndoe",
                        "firstname": "John",
                        "lastname": "Doe",
                    },
                ],
                "teachers": [{"user_id": "u125", "username": "drboolean"}],
            }
        }


class Schoolclasses(BaseModel):  # response model
    groups: List[Schoolclass]


class UdmProperties(BaseModel):
    brokerID: str


class BrokeridUser(BaseModel):
    """Describes a user resource as returned by the kelvin api.
    Only contains fields that we actually use, so that we don't
    need to completely sync model descriptions from both sides.
    """

    udm_properties: UdmProperties
    name: str
    firstname: str
    lastname: str

    class Config:
        orm_mode = True
        extra = "allow"
